#
# spec file for package python-responses
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-responses
Version:        0.10.5
Release:        3.1
Summary:        A utility library for mocking out the `requests` Python library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/getsentry/responses
Source:         https://files.pythonhosted.org/packages/source/r/responses/responses-%{version}.tar.gz
Patch:          tidy-py_modules.patch
BuildRequires:  %{python_module setuptools}
# test requirements
BuildRequires:  %{python_module cookies}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.0}
BuildRequires:  %{python_module six}
BuildRequires:  python-rpm-macros
Requires:       python-cookies
Requires:       python-requests >= 2.0
Requires:       python-six
Suggests:       python-pytest
BuildArch:      noarch
%ifpython2
Requires:       python-mock
%endif
%python_subpackages

%description
A utility library for mocking out the requests Python library.
Check https://github.com/getsentry/responses for more information
about the library.

%prep
%setup -q -n responses-%{version}
# Remove test module from distribution before a .pyc is created
# https://github.com/getsentry/responses/issues/256
%patch -p0

%build
%python_build

%install
%python_install

%check
# `setup.py test` requires additional unnecessary packages
%python_exec -m pytest

%files %{python_files}
%doc CHANGES README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Sun Feb 10 2019 jayvdb@gmail.com
- Activate tests
- Remove test_responses.py from package:
  * tidy-py_modules.patch
- Remove unnecessary build dependencies
- Remove inappropriate Suggests
- Add missing changelog entry for v0.10.5
* Tue Feb  5 2019 adrian.glaubitz@suse.com
- Update to 0.10.5
  + Fix callback exception mocking.
  + Improve test coverage
  + Improve build configuration.
- from version 0.10.4
  + Fixed generated wrapper when using `@responses.activate` in Python 3.6+
    when decorated functions use parameter and/or return annotations.
- from version 0.10.3
  + Fixed deprecation warnings in python 3.7 for inspect module usage.
- from version 0.10.2
  + Fixed build setup to use undeprecated `pytest` bin stub.
  + Updated `tox` configuration.
  + Added example of using responses with `pytest.fixture`.
  + Removed dependency on `biscuits` in py3. Instead `http.cookies` is being used.
- from version 0.10.1
  + Packaging fix to distribute wheel (#219).
- from version 0.10.0
  + Fix passing through extra settings (#207).
  + Fix collections.abc warning on Python 3.7 (#215).
  + Use 'biscuits' library instead of 'cookies' on Python 3.4+ (#218).
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Jul  9 2018 sean.marlow@suse.com
- Update to 0.9.0
  + Support for Python 3.7
  + Support streaming responses for BaseResponse
  + Support custom patch targets for mock
  + Fix unicode support for passthru urls
  + Fix support for unicode in domain names and tlds
* Fri Mar  9 2018 mimi.vx@gmail.com
- Fix python2 requires
* Fri Jan 12 2018 mimi.vx@gmail.com
- update to 0.8.1
  * Added the ability to passthru real requests via ``add_passthru()``
  and ``passthru_prefixes`` configurations.
  * Responses will now be rotated until the final match is hit, and
  then persist using that response (GH-171).
  * Fixed call counting with exceptions (GH-163).
  * Fixed behavior with arbitrary status codes (GH-164).
  * Fixed handling of multiple responses with the same match (GH-165).
  * Fixed default path behavior with ``match_querystring`` (GH-166).
  * Restored ``adding_headers`` compatibility (GH-160).
  * Allow empty list/dict as json object (GH-100).
  * Added `response_callback` (GH-151).
  * Added ``Response`` interfaces (GH-155).
  * Fixed unicode characters in querystring (GH-153).
  * Added support for streaming IO buffers (GH-154).
  * Added support for empty (unset) Content-Type (GH-139).
  * Added reason to mocked responses (GH-132).
  * ``yapf`` autoformatting now enforced on codebase.
* Mon Apr 10 2017 alarrosa@suse.com
- Update for singlespec
* Thu Jan 19 2017 alarrosa@suse.com
- Initial release
